from django.core.paginator import Paginator
from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.press.models import Press, AreaPress
from jmb.press.cms.models import PressListSettings, PressListPerAreaSettings


class PressListPlugin(CMSPluginBase):
    model = PressListSettings
    name = _("Press List")

    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")
        press = Press.objects.filter(status=1)

        if instance.area_slug:
            press = press.objects.filter(area__slug=instance.area_slug)
        if instance.source_slug:
            press = press.objects.filter(source__slug=instance.source_slug)

        press = press.order_by(*ordering)

        request = context['request']
        if request.GET:
            filters = request.GET.copy()
            try:
                press = press.filter(**filters)
            except:
                press.none()

        context.update({
            'objects': press,
            'instance': instance,
            'placeholder': placeholder,
            })
        return context

plugin_pool.register_plugin(PressListPlugin)

class PressListPerAreaPlugin(CMSPluginBase):
    model = PressListPerAreaSettings
    name = _("Press List per Area")

    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name

        ordering_area = instance.ordering_area.lower().replace(" ","").split(",")
        ordering_press = instance.ordering_press.lower().replace(" ","").split(",")

        areas = AreaPress.objects.filter(status=1).order_by(*ordering_area)
        area_list = []

        press = Press.objects.filter(status=1)
        press = press.order_by(*ordering_press)

        request = context['request']
        if request.GET:
            filters = request.GET.copy()
            try:
            #                print filters
                press = press.filter(**filters)
            except Exception, e:
                print e
                press.none()


        for area in areas:
            press_for_area = press.filter(area=area)
            area_dict = {
                'area': area, 'press': press_for_area[0:instance.press_per_page],
                'press_count': press_for_area.count()
            }
            area_list.append(area_dict)

        context.update({
            'area_list': area_list,
            'instance': instance,
            'placeholder': placeholder,
            })
        return context

plugin_pool.register_plugin(PressListPerAreaPlugin)