from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _
from django_extensions.db.fields import AutoSlugField
from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel
from i18n.models import TranslationModel, I18NModel
from jmb.core.db.fields import HTMLField, HTMLFieldTinyMCE

###################################
## MODELS                          #
###################################
class AreaPress(DateModel, UserModel, OrderedModel, StatusModel):
    """
    Un contenitore di notizie.
    """
    name = models.CharField(max_length=64)
    slug = AutoSlugField('slug', populate_from='name', overwrite=True)

    def __unicode__(self):
        return u"%s" % self.name

    class Meta:
        verbose_name_plural = ('AreePress')

class Source(DateModel, UserModel, OrderedModel, StatusModel):
    name = models.CharField(
        unique = True, max_length = 100, db_index = True,
        verbose_name = _('Name')
    )
    slug = models.SlugField(
        max_length = 100, db_index = True,
        verbose_name = _('Slug')
    )

    class Meta:
        verbose_name = _("Source")
        verbose_name_plural = _("Sources")
        ordering = ['name',]

    def __unicode__(self):
        return u"%s" % self.name


class Press(DateModel, UserModel, OrderedModel, StatusModel):
    date_p = models.DateField(
        db_index = True,
        verbose_name = _("Date")
    )
    title = models.CharField(
        max_length = 300, db_index = True,
        verbose_name = _("Testata")
    )
    slug = models.SlugField(
        max_length = 100,
        db_index = True,
        verbose_name = _('Slug'),
    )
    source = models.ForeignKey(
        Source,
        null = True, blank = True,
        db_index = True,
        related_name = "presses",
        verbose_name = _("Source"),
    )
    file = models.FileField (
        null = True, blank = True,
        upload_to = "press",
        verbose_name = _("File"),
    )
    abstract = models.TextField (
        null = True, blank = True,
        verbose_name = _("Titolo"),
    )
    keywords = models.CharField(
        null = True, blank = True,
        max_length = 200,
        db_index = True,
        verbose_name = _("Keywords"),
    )
    area = models.ForeignKey(
        AreaPress,
        related_name = "area_press"
    )


    class Meta:
        verbose_name = _("Press")
        verbose_name_plural = _("Press")
        ordering = ['date_p', 'title']

    def __unicode__(self):
        return u"%s" % self.title

#import cms stuffs
import jmb.press.cms.plugins
import jmb.press.cms.app

